DECLARE SUB Anleitung ()

' ORGAN.BAS: PC ORGAN
' ===================
' Copyright (c) 2004 by Paul  Redling
'
' This program uses the PLAY statement to simulate an organ. It offers all
' the important options to compose a nice tune, including "save" and "load".
' If you want new monophonic ringtones for your mobile phone or some nice
' tunes for your QBasic/QuickBasic program, then PC ORGAN can be very useful.
'
' Compose a tune (cdefgab), record it, save it and then open the file
' TUNE.DAT. You'll get two versions of the tune. The first version includes
' spaces so you can easily read the tune and type it into your cell phone.
' The second version is without spaces and therefore ideal for your program.
' Simply add the PLAY statement. If you want the tune to play in the
' background, then change "mf" at the beginning to "mb". However, the number
' of notes that can be played in the background at one time is limited to 32.
' To make the tune play at a different tempo ("t"), change the default number
' of 120 to a number between 32 (slow) and 255 (fast). You can also add tempo
' settings within the tune to change the tempo of individual parts.
'
' Information on how to use this program
' --------------------------------------
'
' The options "sharp/flat" and "extra length" ("." = 3/2 x length x tempo,
' multiple periods are supported) only apply to a single note. You must press
' the keys "#", "-" and/or "." before you press the individual note
' (cdefgab). The notes e# or f- as well as b# or c- don't exist.
'
' In order to compose a tune, I recommend the following steps: First,
' practice in Normal Mode without using any of the options except "sharp/
' flat" and "octave". Then, when you have the tune you want, "R)ecord" it and
' save ("o") it. Afterwards, use the other options, especially "l)ength", to
' make it sound as good as possible. Finally, when the tune is finished and
' displayed nicely on the screen, delete the file TUNE.DAT, record the
' finished tune and save it. If you only want to convert a tune from some
' song book to the PLAY format, you should record and save it right away.
'
' Don't forget to save the tune while you're in Record Mode because if you
' press "N", the tune will be erased from memory and you can no longer save
' it. Also, with "N" the standard settings ("mfmnt120o2l4") will be restored.
' In order to listen to a saved tune, simply load ("i") it in Normal Mode and
' use "P)layback". To continue a saved tune, use "R)ecord": As a safety
' feature the file TUNE.DAT will always be loaded first and the saved tune
' will be played before you can go on recording. "P)layback" doesn't work in
' Record Mode. Therefore, if you want to listen to the current tune while
' you're in Record Mode, you'll have to save it first. Then you can press
' "R)ecord" as often as you want. You can only record a new tune after you've
' deleted TUNE.DAT. This can be done in Normal Mode. Press "o" and you'll be
' asked if you want to delete TUNE.DAT. If you press "y" or "Y", the file
' will be deleted.
'
'    l)ength and p)ause: 1 - whole note          m)usic: l - legato
'                        2 - 1/2   note                  n - normal
'                        4 - 1/4   note                  s - staccato
'                        8 - 1/8   note
'                        6 - 1/16  note
'                        9 - 1/32  note
'                        0 - 1/64  note
'
'    "mfmnt120o2l4" = music foreground, music normal, tempo 120, octave 2,
'                     length 1/4 note.
'
' Special feature: You can listen to three tunes while you're in Normal Mode.
'                  Simply press "T" followed by a number from 1 to 3. The
'                  classic "Happy Birthday" tune (#1) was composed with this
'                  program. The other two tunes are funny variations of the
'                  "Happy Birthday" tune. They were easy to "compose" after I
'                  had saved the original tune. I copied TUNE.DAT to a new
'                  file, modified the tune in the new file and used the PLAY
'                  statement to listen to the tune.

DEFINT A-Z    'Default data type is integer

DECLARE SUB Center (row, text$)

ON ERROR GOTO FileError    'TUNE.DAT

COLOR 0, 1: CLS
COLOR 0, 3
Center 10, "         "
Center 11, "                 "
Center 12, "    PC ORGAN     "
Center 13, "                 "
Center 14, " By paul redling "
Center 15, "                 "
Center 16, "         "

WHILE INKEY$ = "": WEND

COLOR 0, 7: CLS
COLOR 0, 3
PRINT "                            Compose a Tune (cdefgab)                            "
PRINT " Press Esc to quit, * for cls, <0-6> for octave, #/- for sharp/flat, . for 3/2  "
PRINT "l)ength, p)ause, m)usic, N)ormal, P)layback, R)ecord, disk o)utput, disk i)nput "
PRINT "********************************************************************************"
LOCATE 3, 26: COLOR 0: PRINT "N)ormal"
LOCATE 3, 35: COLOR 1: PRINT "P)layback"
LOCATE 3, 46: COLOR 4: PRINT "R)ecord"
VIEW PRINT 6 TO 25                           'Set up a text viewport
COLOR 0, 7
PRINT "* mfmnt120o2l4 "; : r$ = "mfmnt120o2l4": PLAY r$    'Standard settings

DO
  t$ = INKEY$                                'Main loop: Check each key press
  IF t$ = CHR$(27) THEN
    VIEW PRINT: COLOR 7, 0: CLS 0: END
  ELSEIF t$ = CHR$(42) THEN CLS
  ELSEIF t$ = "<" OR t$ = ">" THEN PRINT t$ + " "; : PLAY t$: IF flag = 1 THEN r$ = r$ + t$ + " "
  ELSEIF t$ = "0" OR t$ = "1" OR t$ = "2" OR t$ = "3" OR t$ = "4" OR t$ = "5" OR t$ = "6" THEN
    IF flag = 1 THEN r$ = r$ + "o" + t$ + " "
    PRINT "o" + t$ + " ";
    PLAY "o" + t$
  ELSEIF t$ = "#" OR t$ = "-" THEN sfxl$ = t$
  ELSEIF t$ = "." THEN sfxl$ = sfxl$ + t$
  ELSEIF t$ = "l" THEN
    PRINT "l";                               'Length 1,2,4,8,6,9,0
    DO
      t1$ = INKEY$
      SELECT CASE t1$
        CASE "1": PRINT "1 "; : PLAY "l1": IF flag = 1 THEN r$ = r$ + "l1 "
        CASE "2": PRINT "2 "; : PLAY "l2": IF flag = 1 THEN r$ = r$ + "l2 "
        CASE "4": PRINT "4 "; : PLAY "l4": IF flag = 1 THEN r$ = r$ + "l4 "
        CASE "8": PRINT "8 "; : PLAY "l8": IF flag = 1 THEN r$ = r$ + "l8 "
        CASE "6": PRINT "16 "; : PLAY "l16": IF flag = 1 THEN r$ = r$ + "l16 "
        CASE "9": PRINT "32 "; : PLAY "l32": IF flag = 1 THEN r$ = r$ + "l32 "
        CASE "0": PRINT "64 "; : PLAY "l64": IF flag = 1 THEN r$ = r$ + "l64 "
        CASE ELSE
      END SELECT
    LOOP UNTIL t1$ = "1" OR t1$ = "2" OR t1$ = "4" OR t1$ = "8" OR t1$ = "6" OR t1$ = "9" OR t1$ = "0"
  ELSEIF t$ = "p" THEN
    PRINT "p";                               'Pause 1,2,4,8,6,9,0
    DO
      t1$ = INKEY$
      SELECT CASE t1$
        CASE "1": PRINT "1 "; : PLAY "p1": IF flag = 1 THEN r$ = r$ + "p1 "
        CASE "2": PRINT "2 "; : PLAY "p2": IF flag = 1 THEN r$ = r$ + "p2 "
        CASE "4": PRINT "4 "; : PLAY "p4": IF flag = 1 THEN r$ = r$ + "p4 "
        CASE "8": PRINT "8 "; : PLAY "p8": IF flag = 1 THEN r$ = r$ + "p8 "
        CASE "6": PRINT "16 "; : PLAY "p16": IF flag = 1 THEN r$ = r$ + "p16 "
        CASE "9": PRINT "32 "; : PLAY "p32": IF flag = 1 THEN r$ = r$ + "p32 "
        CASE "0": PRINT "64 "; : PLAY "p64": IF flag = 1 THEN r$ = r$ + "p64 "
        CASE ELSE
      END SELECT
    LOOP UNTIL t1$ = "1" OR t1$ = "2" OR t1$ = "4" OR t1$ = "8" OR t1$ = "6" OR t1$ = "9" OR t1$ = "0"
  ELSEIF t$ = "m" THEN
    PRINT "m";                               'Music l,n,s
    DO
      t1$ = INKEY$
      SELECT CASE t1$
        CASE "l": PRINT "l "; : PLAY "ml": IF flag = 1 THEN r$ = r$ + "ml "
        CASE "n": PRINT "n "; : PLAY "mn": IF flag = 1 THEN r$ = r$ + "mn "
        CASE "s": PRINT "s "; : PLAY "ms": IF flag = 1 THEN r$ = r$ + "ms "
        CASE ELSE
      END SELECT
    LOOP UNTIL t1$ = "l" OR t1$ = "n" OR t1$ = "s"
  ELSEIF t$ = "N" THEN                       'Normal
    COLOR 0: PRINT "* ";
    flag = 0: r$ = "mfmnt120o2l4 ": sfxl$ = ""
    PRINT r$;
    PLAY r$
  ELSEIF t$ = "P" THEN                       'Playback
    IF flag = 0 THEN
      COLOR 1: PRINT "* ";
      PRINT RTRIM$(r$) + " ";
      PLAY r$
      COLOR 0
    END IF
  ELSEIF t$ = "R" THEN                       'Record
    OPEN "TUNE.DAT" FOR INPUT AS #1
    INPUT #1, r$
    CLOSE #1
    COLOR 4: PRINT "* ";
    flag = 1: sfxl$ = ""
    IF MID$(r$, 1, 1) <> "m" THEN r$ = "mfmnt120o2l4 "
    r$ = RTRIM$(r$) + " ": PRINT r$;
    PLAY r$
  ELSEIF t$ = "o" THEN                       'Disk output
    IF flag = 1 THEN
      FOR n = 1 TO LEN(r$)
        temp$ = MID$(r$, n, 1)
        IF temp$ <> " " THEN r1$ = r1$ + temp$
      NEXT n
      OPEN "TUNE.DAT" FOR OUTPUT AS #1
      PRINT #1, r$
      PRINT #1, ""
      PRINT #1, "** Use the version without spaces for your program **"
      PRINT #1, ""
      PRINT #1, r1$
      CLOSE #1
      r1$ = ""
      COLOR 8: PRINT "(o) "; : COLOR 4
    ELSE
      COLOR 8: PRINT "Delete TUNE.DAT? (Y/N) ";
      DO
        d$ = UCASE$(INKEY$)
        IF d$ = "Y" THEN PRINT "Y "; : KILL "TUNE.DAT": r$ = "mfmnt120o2l4 ": EXIT DO
        IF d$ = "N" THEN PRINT "N "; : EXIT DO
      LOOP
      COLOR 0
    END IF
  ELSEIF t$ = "i" THEN                       'Disk input
    IF flag = 0 THEN
      OPEN "TUNE.DAT" FOR INPUT AS #1
      INPUT #1, r$
      CLOSE #1
      COLOR 8: PRINT "(i) "; : COLOR 0
    END IF
  ELSEIF t$ = "c" OR t$ = "d" OR t$ = "e" OR t$ = "f" OR t$ = "g" OR t$ = "a" OR t$ = "b" THEN
    IF t$ = "e" OR t$ = "b" THEN IF MID$(sfxl$, 1, 1) = "#" THEN sfxl$ = ""
    IF t$ = "f" OR t$ = "c" THEN IF MID$(sfxl$, 1, 1) = "-" THEN sfxl$ = ""
    IF flag = 1 THEN r$ = r$ + t$ + sfxl$ + " "
    PRINT t$ + sfxl$ + " ";
    PLAY t$ + sfxl$                          'Play each note
    sfxl$ = ""
  ELSEIF t$ = "T" THEN                       'Play some finished tunes
    IF flag = 0 THEN
      COLOR 1: PRINT "T";
      DO
        t1$ = INKEY$
        SELECT CASE t1$
          CASE "1"
            PRINT "1 "; "Happy Birthday to You ";
            PLAY "mnt90o2l4cl16cl4dcfl2ep32l4cl16cl4dcgl2fp32l4cl16cl4afee"
            PLAY "l2dp32l4a#l16a#l4afgl2f"
          CASE "2"
            PRINT "2 "; "Happy Birthday to Your Dog ";
            PLAY "mnt90o1l4cl32ccc#l4dcfl2ep32l4cl32ccc#l4dcgl2fp32l4c"
            PLAY "l32ccc#l4afeel2dp32l4a#l16a#l4afgl2f"
          CASE "3"
            PRINT "3 "; "Happy Birthday to Your Alien ";
            PLAY "mnt190o3l2cl8cl4dc#cc#fc#l2ep32l2cl8cl4dc#cc#gc#l2fp32l2c"
            PLAY "l8cl4ac#fc#ec#ec#l2dp32l2a#l8a#l4ac#fc#gc#l2f"
          CASE ELSE
        END SELECT
      LOOP UNTIL t1$ = "1" OR t1$ = "2" OR t1$ = "3"
      COLOR 0: PRINT "* mfmnt120o2l4 "; : r$ = "mfmnt120o2l4": PLAY r$
    END IF
  END IF
LOOP

FileError:
RESUME NEXT

SUB Anleitung

' ORGAN.BAS: PC ORGAN
' ===================
' Copyright (c) 2004 by Paul  Redling
'
' Dieses Programm bentzt die PLAY-Anweisung um eine Orgel zu simulieren. Es
' bietet alle wichtigen Optionen um eine schne Melodie zu komponieren,
' einschlielich "abspeichern" und "laden". Wenn ihr neue einstimmige
' Klingeltne fr euer Handy wollt oder ein paar schne Melodien fr euer
' QBasic/QuickBasic Programm, dann kann PC ORGAN sehr ntzlich sein.
'
' Komponiert eine Melodie (cdefgab), nehmt sie auf, speichert sie ab und dann
' ffnet die Datei TUNE.DAT. Ihr werdet zwei Versionen von der Melodie
' bekommen. Die erste Version enthlt Leerzeichen damit ihr die Melodie
' leicht lesen und in euer Handy eintippen knnt. Die zweite Version ist ohne
' Leerzeichen und deshalb ideal fr euer Programm. Ihr braucht nur die PLAY-
' Anweisung hinzufgen. Wenn ihr wollt, dass die Melodie im Hintergrund
' abgespielt wird, dann ndert "mf" am Anfang in "mb" ab. Die Anzahl der
' Noten, die an einem Stck im Hintergrund abgespielt werden kann, ist jedoch
' auf 32 begrenzt. Um die Melodie mit einem anderen Tempo ("t") abspielen zu
' lassen, ndert die voreingestellte Zahl von 120 auf eine Zahl zwischen 32
' (langsam) und 255 (schnell) ab. Ihr knnt auch innerhalb der Melodie Tempo-
' Einstellungen hinzufgen um das Tempo von einzelnen Abschnitten zu ndern.
'
' Information zur Benutzung dieses Programms
' ------------------------------------------
'
' Die Optionen "Halbtonschritt erhhen/erniedrigen" und "extra Lnge" ("." =
' 3/2 x Lnge x Tempo, mehrere Punkte sind mglich) betreffen nur eine
' einzelne Note. Ihr msst die Tasten "#", "-" und/oder "." drcken bevor ihr
' die einzelne Note (cdefgab) drckt. Die Noten e# oder f- sowie b# oder c-
' existieren nicht.
'
' Um eine Melodie zu komponieren, empfehle ich die folgenden Schritte: bt
' zuerst im Normal-Modus und verwendet dabei keine der Optionen auer
' "Halbtonschritt erhhen/erniedrigen" und "Oktave". Dann, wenn ihr die
' gewnschte Melodie habt, nehmt ihr sie auf ("R)ecord") und speichert ("o")
' sie ab. Danach bentzt ihr die anderen Optionen, vor allem "Lnge"
' ("l)ength"), um sie so gut wie mglich klingen zu lassen. Schlielich, wenn
' die Melodie fertig ist und gut lesbar auf dem Bildschirm angezeigt wird,
' lscht ihr die Datei TUNE.DAT, nehmt die fertige Melodie auf und speichert
' sie ab. Wenn ihr nur eine Melodie aus irgend einem Liederbuch in das PLAY-
' Format umwandeln wollt, dann solltet ihr sie sofort aufnehmen und
' abspeichern.
'
' Vergesst nicht die Melodie abzuspeichern whrend ihr im Aufnahme-Modus
' seid. Denn wenn ihr "N" dckt wird die Melodie aus dem Speicher gelscht
' und ihr knnt sie nicht mehr abspeichern. Mit "N" werden auch die
' Standardeinstellungen ("mfmnt120o2l4") wieder hergestellt. Um eine
' abgespeicherte Melodie anzuhren, ldt ("i") ihr sie einfach im Normal-
' Modus und bentzt "Abspielen" ("P)layback"). Um mit einer abgespeicherten
' Melodie fortzufahren, bentzt ihr "Aufnahme": Zur Sicherheit wird immer
' zuerst die Datei TUNE.DAT geladen und die abgespeicherte Melodie abgespielt
' bevor ihr mit der Aufnahme fortfahren knnt. "Abspielen" funktioniert nicht
' im Aufnahme-Modus. Wenn ihr daher die aktuelle Melodie anhren wollt
' whrend ihr im Aufnahme-Modus seid, dann msst ihr sie zuerst abspeichern.
' Danach knnt ihr "Aufnahme" drcken so oft ihr wollt. Eine neue Melodie
' knnt ihr erst aufnehmen, nachdem ihr TUNE.DAT gelscht habt. Dies knnt
' ihr im Normal-Modus machen. Drckt "o" und ihr werdet gefragt ob ihr
' TUNE.DAT lschen wollt. Wenn ihr "y" oder "Y" drckt, wird die Datei
' gelscht.
'
'    l)nge und p)ause: 1 - ganze Note          m)usik: l - legato
'                       2 - 1/2   Note                  n - normal
'                       4 - 1/4   Note                  s - staccato
'                       8 - 1/8   Note
'                       6 - 1/16  Note
'                       9 - 1/32  Note
'                       0 - 1/64  Note
'
'    "mfmnt120o2l4" = Music Vordergrund, Music normal, Tempo 120, Oktave 2
'                     Lnge 1/4 Note.
'
' Besonderheit: Ihr knnt drei Melodien anhren whrend ihr im Normal-Modus
'               seid. Ihr braucht nur "T" zu drcken, gefolgt von einer Zahl
'               von 1 bis 3. Die klassische "Happy Birthday"-Melodie (#1)
'               wurde mit diesem Programm komponiert. Die anderen zwei
'               Melodien sind lustige Variationen von der "Happy Birthday"-
'               Melodie. Sie waren leicht zu "komponieren" nachdem ich die
'               ursprngliche Melodie abgespeichert hatte. Ich kopierte
'               TUNE.DAT in eine neue Datei, nderte die Melodie in der neuen
'               Datei und bentzte die PLAY-Anweisung um die Melodie
'               anzuhren.

END SUB

SUB Center (row, text$)

LOCATE row, (80 - LEN(text$)) \ 2 + 1
PRINT text$;

END SUB

